import StatusIndicator from '@cloudscape-design/components/status-indicator';
import { ReactWidget } from '@jupyterlab/apputils';
import { TextItem, showPopup } from '@jupyterlab/statusbar';
import React, { useState } from 'react';
import { CodeScanErrorWidget, ErrorType } from './CodeScanErrorPopup';
const statusCleanupTimeout = {
    completed: 5000,
    error: 30000,
    idle: 0
};
function CodeScanStatusComponent(props) {
    const [status, setStatus] = useState(props.status);
    const [message, setMessage] = useState();
    props.listener.connect((_, { status, message }) => {
        if (status !== 'pending') {
            setTimeout(() => {
                setStatus('idle'); // It will remove the status from footer
            }, statusCleanupTimeout[status]);
        }
        setStatus(status);
        setMessage(message);
    });
    switch (status) {
        case 'pending': {
            const title = 'CodeGuru: Scan in progress';
            return (React.createElement(StatusIndicator, { type: "in-progress", colorOverride: "blue" },
                React.createElement(TextItem, { source: title })));
        }
        case 'error': {
            const errorType = parseError(String(message));
            const title = errorType === ErrorType.INSUFFICIENT_ACCESS_PERMISSIONS
                ? 'CodeGuru: Missing permissions'
                : errorType === ErrorType.MISSING_AWS_CREDENTIALS
                    ? 'CodeGuru: Missing credentials'
                    : 'CodeGuru: Scan failed';
            return (React.createElement("div", { onClick: () => props.handleClick(errorType) },
                React.createElement(StatusIndicator, { type: "warning" },
                    React.createElement(TextItem, { source: title }))));
        }
        case 'completed': {
            const title = 'CodeGuru: Scan completed';
            return (React.createElement(StatusIndicator, { type: "success", colorOverride: "blue" },
                React.createElement(TextItem, { source: title })));
        }
        case 'idle':
        default:
            return React.createElement(React.Fragment, null);
    }
}
export class CodeScanStatus extends ReactWidget {
    constructor(props) {
        super();
        this._popup = null;
        this.status = props.status;
        this.listener = props.listener;
        this.handleClick = this.handleClick.bind(this);
    }
    handleClick(errorType) {
        var _a;
        if (!errorType) {
            return;
        }
        if ((_a = this._popup) === null || _a === void 0 ? void 0 : _a.isVisible) {
            this._popup.close();
        }
        else {
            if (this._popup) {
                this._popup.dispose();
            }
            this._popup = showPopup({
                body: new CodeScanErrorWidget({ errorType }),
                anchor: this,
                align: 'left'
            });
        }
    }
    render() {
        return (React.createElement(CodeScanStatusComponent, { status: this.status, listener: this.listener, handleClick: this.handleClick }));
    }
}
export function parseError(message) {
    if (!message) {
        return;
    }
    if (message.includes('AccessDeniedException') &&
        message.includes('not authorized to perform: codeguru-security')) {
        return ErrorType.INSUFFICIENT_ACCESS_PERMISSIONS;
    }
    if ((message.includes('UnrecognizedClientException') ||
        message.includes('ExpiredTokenException')) &&
        message.includes('The security token included in the request is ')) {
        return ErrorType.MISSING_AWS_CREDENTIALS;
    }
    return;
}
